Caissa
======

.. image:: https://travis-ci.org/ddobbelaere/caissa.svg?branch=master
    :target: https://travis-ci.org/ddobbelaere/caissa
.. image:: https://bestpractices.coreinfrastructure.org/projects/1959/badge
    :target: https://bestpractices.coreinfrastructure.org/projects/1959
    :alt: CII Best Practices

Caissa is an intelligent voice-controlled personal assistant (still under development).

Some of her upcoming skills include

  - play your favorite internet radio
  - play chess
  - monitor live chess games
  - help you study foreign languages
  
.. image:: https://github.com/ddobbelaere/caissa/raw/master/doc/caissa.png
    :align: center
    :alt: Overview of the different components of Caissa